module.exports = function init() {
    if (!window.mjfKit) { 
        // if mjfKit isn't already initialised, set it up
        // and append to the window object    

        window.mjfKit = {
            inc: 0, // counter for spacing labels to avoid clashing
            
            // not used directly in the final composition version, but referenced by note.
            // contains extensive redundant functionality 
            curve: function (context,startRatio, endRatio, curvePosRatio, lineWidth, colour, label, dasharray) {
                var myID = context.attr("id") + "svg";
                var myContext = $("#" + myID);
                var dimen = [800, 600];
                if (!colour)
                    colour = "blue";
                var start = dimen[1] * (1 - startRatio);
                var end = dimen[1] * (1 - endRatio);
                var type;
                if (startRatio === endRatio || curvePosRatio === -1) {
                    type = "line";
                    var pathdata = {
                        fill: "transparent",
                        "stroke-width": lineWidth,
                        stroke: colour,
                        x1: 0, x2: dimen[0],
                        y1: start, y2: end
                    };
                    curvePosRatio = 0;
                } else { 
                    type = "path";
                    var pathdata = {
                        fill: "transparent",
                        "stroke-width": lineWidth,
                        stroke: colour,
                        d: "M" + -lineWidth * .5 + " " + start + " C0,100 " + (dimen[0] * curvePosRatio) + " 10," + (dimen[0] + (lineWidth * .5)) + "," + end
                    };
                }
                if (dasharray) // ability to apply a patern to the line from dasharray
                    pathdata["stroke-dasharray"] = dasharray;
                var t = $("<" + type + " />", pathdata);
                var xd = start + 20;
                if (start > dimen[1] * 0.8)
                    xd = dimen[1] * 0.8;
                myContext.append(t);
                
                if (label) { // text labelling, if label arg is supplied
                    var scolour = (colour === "black") ? "white" : colour; 
                    var i = $("<text />", {
                        x: 10,
                        y: xd,
                        "font-family": "sans-serif",
                        "font-weight": "bold",
                        "font-size": "26px",
                        "stroke": scolour,
                        "stroke-width": 1
                    }).text(label);
                    window.mjfKit.inc += 24;
                }
                myContext.append(i);
                context.html(context.html());
            },
            
            // append a note to a svg context
            note: function (context,pitch, start, length, colour) {
                var dimen = [800, 600];
                var pitchstart, pitchend;
                if (pitch instanceof Array) {
                    pitchstart = pitch[0];
                    pitchend = pitch[1];
                } else {
                    pitchstart = pitchend = pitch;
                }
                window.mjfKit.curve(context,pitchstart, pitchend, -1, 10, colour, null, "0," + (dimen[0]) * start + " " + dimen[0] * length + " 800,1000");
            },
            
            
            // create a svg image with data and append to context div
            notes: function (context,data) {
                var myID = context.attr("id") + "svg";
                var svg = $("<svg />", {
                    id: myID,
                    viewBox: "0 0 800 600"
                }).css("left", "0px").css("top", "0px");
                context.append(svg);
                for (var t in data) {
                    window.mjfKit.note(context,data[t][3], data[t][1], data[t][2]*2, data[t][0]);
                }
            }

        };
    }

};


